Function disassemble::find_loops [] [src]

pub fn find_loops<'havlak>(
    cfg: &'havlak ControlFlowGraph,
    _lsg: &'havlak mut LoopStructureGraph<'havlak>
) -> usize

Find loops and build loop forest using Havlak's algorithm, which is derived from Tarjan.

Variable names and step numbering has been chosen to be identical to the nomenclature in Havlak's paper (which, in turn, is similar to the one used by Tarjan).