Struct disassemble::BasicBlock
[−]
[src]
pub struct BasicBlock {
pub name: Option<String>,
pub address: Address,
pub instruction_indices: Vec<usize>,
}A basic block is a sequence of instructions with no inward-bound branches except to the entry point and no outward-bound branches except at the exit.
Fields
name: Option<String>
The name of the basic block. Not all blocks have meaningful names.
address: Address
The address of the first instruction in the basic block.
instruction_indices: Vec<usize>
The indices instructions within this basic block.